##  Edit and Delete Milestones
To edit or delete a Milestone, follow the below instructions:
  1. Hover over the Milestone you want to edit or delete, and you will see the Edit button appear.
  2. Click Edit.
  3. Make the necessary edits to the required fields, and then click Save to finalize the changes. If you want to delete the Milestone, click Delete.


It is also possible to edit Milestones in the Inventory's table view. Simply double-click on the date field you wish to modify and select the desired Milestone. For a more detailed guide on editing in table view mode, refer to the instructions provided in [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.").
![Editing Milestones in table view of Inventory](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274a77e97a4410148fe4bbbf46061457_LowRes.png)
Editing Milestones in table view of Inventory
